@@ -47,7 +47,7 @@ pam_sm_authenticate (pam_handle_t  *pamh,
                 return PAM_AUTHINFO_UNAVAIL;
 
         r = keyctl_read_alloc (serial, &cached_password);
-        if (r < 0 || r != strlen (cached_password))
+        if (r < 0)
                 return PAM_AUTHINFO_UNAVAIL;
 
         r = pam_set_item (pamh, PAM_AUTHTOK, cached_password);
@@ -56,11 +56,9 @@ pam_sm_authenticate (pam_handle_t  *pamh,
 
         if (r < 0)
                 return PAM_AUTH_ERR;
-        else
-                return PAM_SUCCESS;
 #endif
 
-        return PAM_AUTHINFO_UNAVAIL;
+        return PAM_SUCCESS;
 }
 
 int
